@@ -12,6 +12,7 @@ import pysam
 import requests
 from LRphase import PhasableSample
 from pysam import VariantFile
+from LRphase import urls
 
 
 def _prepare_output_directory(output_directory_path: str) -> object:#Optional[str]:
@@ -361,7 +362,7 @@ class InputData:
     """
     output_directory: object
     try:
-        import urls
+        from LRphase import urls
         urls_found = True
     except:
         print('Could not find import urls from data. Data will not be able to downloaded from example web sources.')
@@ -569,6 +570,7 @@ class InputData:
         """
         """
         vcf_file_path = self._prepare_vcf_file(self.output_directory, vcf_file_input)
+        print("{}\n".format(vcf_file_path))
         if pysam.VariantFile(vcf_file_path).header.formats.keys().count('PS') == 0:
             ignore_phase_sets = True
             print(
@@ -579,10 +581,11 @@ class InputData:
                                 "contiguous haploblock "
                     )
         self.vcf_files.append({vcf_file_path:ignore_phase_sets})
-        self.sample_to_vcf_file_dict = self._sample_to_vcf_file_dict(self.vcf_files)
+        self.sample_to_vcf_file_dict = _sample_to_vcf_file_dict(self.vcf_files)
         self.sample_to_alignment_files = _sample_to_alignment_files(self.sample_to_vcf_file_dict, self.RG_ID_dict)
         self._sample_to_reference_sequences_dict()
         self._sample_to_PG_dict()
+        return vcf_file_path
     
     def __iter__(self):
         self.sample_counter = 0
