@@ -5,7 +5,7 @@ from collections import defaultdict
 #import numpy as np
 import pyliftover
 
-import PhaseSet
+from LRphase import PhaseSet
 
 
 def true_alignment_match(
@@ -24,7 +24,7 @@ def true_alignment_match(
         haplotype: object = None,
         reference_liftover_converters: object = None) -> object:
     """
-Args:
+    Args:
     aligned_segment:
     needs_liftover:
     contig:
@@ -41,10 +41,10 @@ Args:
     sample:
     haplotype:
     reference_liftover_converters:
-
-Returns:
-
-"""
+    
+    Returns:
+    
+    """
     overlap = 0
     match_label = 'non_match'
     
@@ -79,47 +79,47 @@ Returns:
         ref_end = liftover_converter.convert_coordinate(contig, ref_end)[0][1]
         strand = liftover_converter.convert_coordinate(contig, ref_start)[0][2]
 
-if aligned_segment.reference_name == contig:
-    match_label = 'ref_match'
-    if int(aligned_segment.reference_start) >= int(ref_start) and int(aligned_segment.reference_start) <= int(
-            ref_end
-            ):
-        match_label = 'mapping_match'
-        if int(aligned_segment.reference_end) >= int(ref_end):
-            overlap = int(ref_end) - int(aligned_segment.reference_start)
+        if aligned_segment.reference_name == contig:
+            match_label = 'ref_match'
+            if int(aligned_segment.reference_start) >= int(ref_start) and int(aligned_segment.reference_start) <= int(
+                    ref_end
+                    ):
+                match_label = 'mapping_match'
+                if int(aligned_segment.reference_end) >= int(ref_end):
+                    overlap = int(ref_end) - int(aligned_segment.reference_start)
+                else:
+                    overlap = int(aligned_segment.reference_end) - int(aligned_segment.reference_start)
+            elif int(aligned_segment.reference_end) >= int(ref_start) and int(aligned_segment.reference_end) <= int(
+                    ref_end
+                    ):
+                match_label = 'mapping_match'
+                if int(ref_start) >= int(aligned_segment.reference_start):
+                    overlap = int(aligned_segment.reference_end) - int(ref_start)
+                else:
+                    overlap = int(aligned_segment.reference_end) - int(aligned_segment.reference_start)
+            elif aligned_segment.reference_start >= (
+                    int(ref_start) - (int(ref_start) * 0.1)) and aligned_segment.reference_start <= (
+                    int(ref_end) + (int(ref_end) * 0.1)):
+                match_label = 'within_10percent'
+
+        if tag_read:
+            aligned_segment.set_tag(
+                    tag = 'ov', value = str(overlap / (int(ref_end) - int(ref_start))), value_type = 'Z', replace = True
+                    )
+            aligned_segment.set_tag(
+                    tag = 'OV', value = str(overlap / (aligned_segment.query_alignment_length)), value_type = 'Z',
+                    replace = True
+                    )
+            aligned_segment.set_tag(tag = 'ml', value = str(match_label), value_type = 'Z', replace = True)
+
+        if only_output_match_label:
+            return match_label
+
+        elif only_output_overlap:
+            return overlap
+
         else:
-            overlap = int(aligned_segment.reference_end) - int(aligned_segment.reference_start)
-    elif int(aligned_segment.reference_end) >= int(ref_start) and int(aligned_segment.reference_end) <= int(
-            ref_end
-            ):
-        match_label = 'mapping_match'
-        if int(ref_start) >= int(aligned_segment.reference_start):
-            overlap = int(aligned_segment.reference_end) - int(ref_start)
-        else:
-            overlap = int(aligned_segment.reference_end) - int(aligned_segment.reference_start)
-    elif aligned_segment.reference_start >= (
-            int(ref_start) - (int(ref_start) * 0.1)) and aligned_segment.reference_start <= (
-            int(ref_end) + (int(ref_end) * 0.1)):
-        match_label = 'within_10percent'
-
-if tag_read:
-    aligned_segment.set_tag(
-            tag = 'ov', value = str(overlap / (int(ref_end) - int(ref_start))), value_type = 'Z', replace = True
-            )
-    aligned_segment.set_tag(
-            tag = 'OV', value = str(overlap / (aligned_segment.query_alignment_length)), value_type = 'Z',
-            replace = True
-            )
-    aligned_segment.set_tag(tag = 'ml', value = str(match_label), value_type = 'Z', replace = True)
-
-if only_output_match_label:
-    return match_label
-
-elif only_output_overlap:
-    return overlap
-
-else:
-    return match_label, overlap
+            return match_label, overlap
 
 
 def true_alignment_coordinates(
